@@ -534,7 +534,7 @@ def contracted_nodes(G, u, v, self_loops=True, copy=True):
 identified_nodes = contracted_nodes
 
 
-def contracted_edge(G, edge, self_loops=True):
+def contracted_edge(G, edge, self_loops=True, copy=True):
     """Returns the graph that results from contracting the specified edge.
 
     Edge contraction identifies the two endpoints of the edge as a single node
@@ -555,6 +555,10 @@ def contracted_edge(G, edge, self_loops=True):
        endpoints of `edge` in `G` become self-loops on the new node in the
        returned graph.
 
+    copy : Boolean (default True)
+        If this is True, a the contraction will be performed on a copy of `G`,
+        otherwise the contraction will happen in place.
+
     Returns
     -------
     Networkx graph
@@ -596,4 +600,4 @@ def contracted_edge(G, edge, self_loops=True):
     u, v = edge[:2]
     if not G.has_edge(u, v):
         raise ValueError(f"Edge {edge} does not exist in graph G; cannot contract it")
-    return contracted_nodes(G, u, v, self_loops=self_loops)
+    return contracted_nodes(G, u, v, self_loops=self_loops, copy=copy)
