@@ -17,14 +17,15 @@ __all__ = [
 def union(G, H, rename=(None, None), name=None):
     """Return the union of graphs G and H.
 
-    Graphs G and H must be disjoint, otherwise an exception is raised.
+    Graphs G and H must be disjoint after the renaming takes place,
+    otherwise an exception is raised.
 
     Parameters
     ----------
     G,H : graph
        A NetworkX graph
 
-    rename : bool , default=(None, None)
+    rename : tuple , default=(None, None)
        Node names of G and H can be changed by specifying the tuple
        rename=('G-','H-') (for example).  Node "u" in G is then renamed
        "G-u" and "v" in H is renamed "H-v".
@@ -32,6 +33,9 @@ def union(G, H, rename=(None, None), name=None):
     name : string
        Specify the name for the union graph
 
+       .. deprecated:: 2.7
+           This is deprecated and will be removed in version v3.0.
+
     Returns
     -------
     U : A union graph with the same type as G.
@@ -45,61 +49,30 @@ def union(G, H, rename=(None, None), name=None):
     to the union graph.  If a graph attribute is present in both
     G and H the value from H is used.
 
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2), (1, 2)])
+    >>> H = nx.Graph([(0, 1), (0, 3), (1, 3), (1, 2)])
+    >>> U = nx.union(G, H, rename=("G", "H"))
+    >>> U.nodes
+    NodeView(('G0', 'G1', 'G2', 'H0', 'H1', 'H3', 'H2'))
+    >>> U.edges
+    EdgeView([('G0', 'G1'), ('G0', 'G2'), ('G1', 'G2'), ('H0', 'H1'), ('H0', 'H3'), ('H1', 'H3'), ('H1', 'H2')])
+
     See Also
     --------
     disjoint_union
     """
-    if not G.is_multigraph() == H.is_multigraph():
-        raise nx.NetworkXError("G and H must both be graphs or multigraphs.")
-    # Union is the same type as G
-    R = G.__class__()
-    # add graph attributes, H attributes take precedent over G attributes
-    R.graph.update(G.graph)
-    R.graph.update(H.graph)
+    if name is not None:
+        import warnings
 
-    # rename graph to obtain disjoint node labels
-    def add_prefix(graph, prefix):
-        if prefix is None:
-            return graph
-
-        def label(x):
-            if isinstance(x, str):
-                name = prefix + x
-            else:
-                name = prefix + repr(x)
-            return name
-
-        return nx.relabel_nodes(graph, label)
-
-    G = add_prefix(G, rename[0])
-    H = add_prefix(H, rename[1])
-    if set(G) & set(H):
-        raise nx.NetworkXError(
-            "The node sets of G and H are not disjoint.",
-            "Use appropriate rename=(Gprefix,Hprefix)" "or use disjoint_union(G,H).",
+        warnings.warn(
+            "name parameter is deprecated and will be removed in version 3.0",
+            DeprecationWarning,
+            stacklevel=2,
         )
-    if G.is_multigraph():
-        G_edges = G.edges(keys=True, data=True)
-    else:
-        G_edges = G.edges(data=True)
-    if H.is_multigraph():
-        H_edges = H.edges(keys=True, data=True)
-    else:
-        H_edges = H.edges(data=True)
 
-    # add nodes
-    R.add_nodes_from(G)
-    R.add_nodes_from(H)
-    # add edges
-    R.add_edges_from(G_edges)
-    R.add_edges_from(H_edges)
-    # add node attributes
-    for n in G:
-        R.nodes[n].update(G.nodes[n])
-    for n in H:
-        R.nodes[n].update(H.nodes[n])
-
-    return R
+    return nx.union_all([G, H], rename)
 
 
 def disjoint_union(G, H):
@@ -127,13 +100,20 @@ def disjoint_union(G, H):
     Graph, edge, and node attributes are propagated from G and H
     to the union graph.  If a graph attribute is present in both
     G and H the value from H is used.
+
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2), (1, 2)])
+    >>> H = nx.Graph([(0, 3), (1, 2), (2, 3)])
+    >>> G.nodes[0]["key1"] = 5
+    >>> H.nodes[0]["key2"] = 10
+    >>> U = nx.disjoint_union(G, H)
+    >>> U.nodes(data=True)
+    NodeDataView({0: {'key1': 5}, 1: {}, 2: {}, 3: {'key2': 10}, 4: {}, 5: {}, 6: {}})
+    >>> U.edges
+    EdgeView([(0, 1), (0, 2), (1, 2), (3, 4), (4, 6), (5, 6)])
     """
-    R1 = nx.convert_node_labels_to_integers(G)
-    R2 = nx.convert_node_labels_to_integers(H, first_label=len(R1))
-    R = union(R1, R2)
-    R.graph.update(G.graph)
-    R.graph.update(H.graph)
-    return R
+    return nx.disjoint_union_all([G, H])
 
 
 def intersection(G, H):
@@ -166,34 +146,18 @@ def intersection(G, H):
     >>> R = G.copy()
     >>> R.remove_nodes_from(n for n in G if n not in H)
     >>> R.remove_edges_from(e for e in G.edges if e not in H.edges)
+
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2), (1, 2)])
+    >>> H = nx.Graph([(0, 3), (1, 2), (2, 3)])
+    >>> R = nx.intersection(G, H)
+    >>> R.nodes
+    NodeView((0, 1, 2))
+    >>> R.edges
+    EdgeView([(1, 2)])
     """
-    if not G.is_multigraph() == H.is_multigraph():
-        raise nx.NetworkXError("G and H must both be graphs or multigraphs.")
-
-    # create new graph
-    if set(G) != set(H):
-        R = G.__class__()
-        R.add_nodes_from(set(G.nodes).intersection(set(H.nodes)))
-    else:
-        R = nx.create_empty_copy(G)
-
-    if G.number_of_edges() <= H.number_of_edges():
-        if G.is_multigraph():
-            edges = G.edges(keys=True)
-        else:
-            edges = G.edges()
-        for e in edges:
-            if H.has_edge(*e):
-                R.add_edge(*e)
-    else:
-        if H.is_multigraph():
-            edges = H.edges(keys=True)
-        else:
-            edges = H.edges()
-        for e in edges:
-            if G.has_edge(*e):
-                R.add_edge(*e)
-    return R
+    return nx.intersection_all([G, H])
 
 
 def difference(G, H):
@@ -204,7 +168,7 @@ def difference(G, H):
     Parameters
     ----------
     G,H : graph
-       A NetworkX graph.  G and H must have the same node sets.
+       A NetworkX graph. G and H must have the same node sets.
 
     Returns
     -------
@@ -221,6 +185,16 @@ def difference(G, H):
     >>> H = nx.path_graph(5)
     >>> R = G.copy()
     >>> R.remove_nodes_from(n for n in G if n in H)
+
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2), (1, 2), (1, 3)])
+    >>> H = nx.Graph([(0, 1), (1, 2), (0, 3)])
+    >>> R = nx.difference(G, H)
+    >>> R.nodes
+    NodeView((0, 1, 2, 3))
+    >>> R.edges
+    EdgeView([(0, 2), (1, 3)])
     """
     # create new graph
     if not G.is_multigraph() == H.is_multigraph():
@@ -258,6 +232,16 @@ def symmetric_difference(G, H):
     -----
     Attributes from the graph, nodes, and edges are not copied to the new
     graph.
+
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2), (1, 2), (1, 3)])
+    >>> H = nx.Graph([(0, 1), (1, 2), (0, 3)])
+    >>> R = nx.symmetric_difference(G, H)
+    >>> R.nodes
+    NodeView((0, 1, 2, 3))
+    >>> R.edges
+    EdgeView([(0, 2), (0, 3), (1, 3)])
     """
     # create new graph
     if not G.is_multigraph() == H.is_multigraph():
@@ -315,27 +299,18 @@ def compose(G, H):
     For MultiGraphs, the edges are identified by incident nodes AND edge-key.
     This can cause surprises (i.e., edge `(1, 2)` may or may not be the same
     in two graphs) if you use MultiGraph without keeping track of edge keys.
+
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2)])
+    >>> H = nx.Graph([(0, 1), (1, 2)])
+    >>> R = nx.compose(G, H)
+    >>> R.nodes
+    NodeView((0, 1, 2))
+    >>> R.edges
+    EdgeView([(0, 1), (0, 2), (1, 2)])
     """
-    if not G.is_multigraph() == H.is_multigraph():
-        raise nx.NetworkXError("G and H must both be graphs or multigraphs.")
-
-    R = G.__class__()
-    # add graph attributes, H attributes take precedent over G attributes
-    R.graph.update(G.graph)
-    R.graph.update(H.graph)
-
-    R.add_nodes_from(G.nodes(data=True))
-    R.add_nodes_from(H.nodes(data=True))
-
-    if G.is_multigraph():
-        R.add_edges_from(G.edges(keys=True, data=True))
-    else:
-        R.add_edges_from(G.edges(data=True))
-    if H.is_multigraph():
-        R.add_edges_from(H.edges(keys=True, data=True))
-    else:
-        R.add_edges_from(H.edges(data=True))
-    return R
+    return nx.compose_all([G, H])
 
 
 def full_join(G, H, rename=(None, None)):
@@ -351,7 +326,7 @@ def full_join(G, H, rename=(None, None)):
     G, H : graph
        A NetworkX graph
 
-    rename : bool , default=(None, None)
+    rename : tuple , default=(None, None)
        Node names of G and H can be changed by specifying the tuple
        rename=('G-','H-') (for example).  Node "u" in G is then renamed
        "G-u" and "v" in H is renamed "H-v".
@@ -376,6 +351,16 @@ def full_join(G, H, rename=(None, None)):
     to the union graph.  If a graph attribute is present in both
     G and H the value from H is used.
 
+    Examples
+    --------
+    >>> G = nx.Graph([(0, 1), (0, 2)])
+    >>> H = nx.Graph([(3, 4)])
+    >>> R = nx.full_join(G, H, rename=("G", "H"))
+    >>> R.nodes
+    NodeView(('G0', 'G1', 'G2', 'H3', 'H4'))
+    >>> R.edges
+    EdgeView([('G0', 'G1'), ('G0', 'G2'), ('G0', 'H3'), ('G0', 'H4'), ('G1', 'H3'), ('G1', 'H4'), ('G2', 'H3'), ('G2', 'H4'), ('H3', 'H4')])
+
     See Also
     --------
     union
