@@ -1,5 +1,6 @@
 import networkx as nx
-#from networkx.generators.smax import li_smax_graph
+
+__all__ = ["s_metric"]
 
 
 def s_metric(G, normalized=True):
@@ -31,7 +32,7 @@ def s_metric(G, normalized=True):
     """
     if normalized:
         raise nx.NetworkXError("Normalization not implemented")
-#        Gmax = li_smax_graph(list(G.degree().values()))
-#        return s_metric(G,normalized=False)/s_metric(Gmax,normalized=False)
-#    else:
-    return float(sum([G.degree(u) * G.degree(v) for (u, v) in G.edges()]))
+    #        Gmax = li_smax_graph(list(G.degree().values()))
+    #        return s_metric(G,normalized=False)/s_metric(Gmax,normalized=False)
+    #    else:
+    return float(sum(G.degree(u) * G.degree(v) for (u, v) in G.edges()))
