@@ -5,12 +5,20 @@ import pytest
 np = pytest.importorskip("numpy")
 
 
-def test_non_randomness():
+@pytest.mark.parametrize(
+    "k, weight, expected",
+    [
+        (None, None, 7.21),  # infers 3 communities
+        (2, None, 11.7),
+        (None, "weight", 25.45),
+        (2, "weight", 38.8),
+    ],
+)
+def test_non_randomness(k, weight, expected):
     G = nx.karate_club_graph()
-    np.testing.assert_almost_equal(nx.non_randomness(G, 2)[0], 11.7, decimal=2)
     np.testing.assert_almost_equal(
-        nx.non_randomness(G)[0], 7.21, decimal=2
-    )  # infers 3 communities
+        nx.non_randomness(G, k, weight)[0], expected, decimal=2
+    )
 
 
 def test_non_connected():
