@@ -1,5 +1,4 @@
-
-from nose.tools import assert_equal, raises
+import pytest
 
 import networkx as nx
 
@@ -11,11 +10,13 @@ def test_smetric():
     g.add_edge(2, 4)
     g.add_edge(1, 4)
     sm = nx.s_metric(g, normalized=False)
-    assert_equal(sm, 19.0)
+    assert sm == 19.0
+
+
 #    smNorm = nx.s_metric(g,normalized=True)
 #    assert_equal(smNorm, 0.95)
 
 
-@raises(nx.NetworkXError)
 def test_normalized():
-    sm = nx.s_metric(nx.Graph(), normalized=True)
+    with pytest.raises(nx.NetworkXError):
+        sm = nx.s_metric(nx.Graph(), normalized=True)
