@@ -762,8 +762,8 @@ def complete_multipartite_graph(*subset_sizes):
     try:
         for (i, subset) in enumerate(subsets):
             G.add_nodes_from(subset, subset=i)
-    except TypeError as e:
-        raise NetworkXError("Arguments must be all ints or all iterables") from e
+    except TypeError as err:
+        raise NetworkXError("Arguments must be all ints or all iterables") from err
 
     # Across subsets, all nodes should be adjacent.
     # We can use itertools.combinations() because undirected.
