@@ -4,6 +4,12 @@ GraphML
 *******
 Read and write graphs in GraphML format.
 
+.. warning::
+
+    This parser uses the standard xml library present in Python, which is
+    insecure - see :doc:`library/xml` for additional information.
+    Only parse GraphML files you trust.
+
 This implementation does not support mixed graphs (directed and unidirected
 edges together), hyperedges, nested graphs, or ports.
 
@@ -441,6 +447,17 @@ class GraphML:
         1: True,
     }
 
+    def get_xml_type(self, key):
+        """Wrapper around the xml_type dict that raises a more informative
+        exception message when a user attempts to use data of a type not
+        supported by GraphML."""
+        try:
+            return self.xml_type[key]
+        except KeyError as err:
+            raise TypeError(
+                f"GraphML does not support type {type(key)} as data values."
+            ) from err
+
 
 class GraphMLWriter(GraphML):
     def __init__(
@@ -498,7 +515,7 @@ class GraphMLWriter(GraphML):
             types = self.attribute_types[(name, scope)]
 
             if len(types) > 1:
-                types = {self.xml_type[t] for t in types}
+                types = {self.get_xml_type(t) for t in types}
                 if "string" in types:
                     return str
                 elif "float" in types or "double" in types:
@@ -545,7 +562,7 @@ class GraphMLWriter(GraphML):
             raise nx.NetworkXError(
                 f"GraphML writer does not support {element_type} as data values."
             )
-        keyid = self.get_key(name, self.xml_type[element_type], scope, default)
+        keyid = self.get_key(name, self.get_xml_type(element_type), scope, default)
         data_element = self.myElement("data", key=keyid)
         data_element.text = str(value)
         return data_element
@@ -759,7 +776,7 @@ class GraphMLWriterLxml(GraphMLWriter):
         for k, v in graphdata.items():
             self.attribute_types[(str(k), "graph")].add(type(v))
         for k, v in graphdata.items():
-            element_type = self.xml_type[self.attr_type(k, "graph", v)]
+            element_type = self.get_xml_type(self.attr_type(k, "graph", v))
             self.get_key(str(k), element_type, "graph", None)
         # Nodes and data
         for node, d in G.nodes(data=True):
@@ -767,7 +784,7 @@ class GraphMLWriterLxml(GraphMLWriter):
                 self.attribute_types[(str(k), "node")].add(type(v))
         for node, d in G.nodes(data=True):
             for k, v in d.items():
-                T = self.xml_type[self.attr_type(k, "node", v)]
+                T = self.get_xml_type(self.attr_type(k, "node", v))
                 self.get_key(str(k), T, "node", node_default.get(k))
         # Edges and data
         if G.is_multigraph():
@@ -776,7 +793,7 @@ class GraphMLWriterLxml(GraphMLWriter):
                     self.attribute_types[(str(k), "edge")].add(type(v))
             for u, v, ekey, d in G.edges(keys=True, data=True):
                 for k, v in d.items():
-                    T = self.xml_type[self.attr_type(k, "edge", v)]
+                    T = self.get_xml_type(self.attr_type(k, "edge", v))
                     self.get_key(str(k), T, "edge", edge_default.get(k))
         else:
             for u, v, d in G.edges(data=True):
@@ -784,7 +801,7 @@ class GraphMLWriterLxml(GraphMLWriter):
                     self.attribute_types[(str(k), "edge")].add(type(v))
             for u, v, d in G.edges(data=True):
                 for k, v in d.items():
-                    T = self.xml_type[self.attr_type(k, "edge", v)]
+                    T = self.get_xml_type(self.attr_type(k, "edge", v))
                     self.get_key(str(k), T, "edge", edge_default.get(k))
 
         # Now add attribute keys to the xml file
@@ -948,8 +965,8 @@ class GraphMLReader(GraphML):
             try:
                 data_name = graphml_keys[key]["name"]
                 data_type = graphml_keys[key]["type"]
-            except KeyError as e:
-                raise nx.NetworkXError(f"Bad GraphML data: no key {key}") from e
+            except KeyError as err:
+                raise nx.NetworkXError(f"Bad GraphML data: no key {key}") from err
             text = data_element.text
             # assume anything with subelements is a yfiles extension
             if text is not None and len(list(data_element)) == 0:
@@ -982,14 +999,14 @@ class GraphMLReader(GraphML):
                     data["label"] = node_label.text
 
                 # check all the different types of edges avaivable in yEd.
-                for e in [
+                for edge_type in [
                     "PolyLineEdge",
                     "SplineEdge",
                     "QuadCurveEdge",
                     "BezierEdge",
                     "ArcEdge",
                 ]:
-                    pref = f"{{{self.NS_Y}}}{e}/{{{self.NS_Y}}}"
+                    pref = f"{{{self.NS_Y}}}{edge_type}/{{{self.NS_Y}}}"
                     edge_label = data_element.find(f"{pref}EdgeLabel")
                     if edge_label is not None:
                         break
