@@ -1,32 +1,48 @@
-# -*- coding: utf-8 -*-
-#    Copyright (C) 2017 NetworkX Developers
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    Loïc Séguin-C. <loicseguin@gmail.com>
-#    All rights reserved.
-#    BSD license.
 """
 Algorithms for calculating min/max spanning trees/forests.
 
 """
+from dataclasses import dataclass, field
+from enum import Enum
 from heapq import heappop, heappush
 from operator import itemgetter
 from itertools import count
 from math import isnan
+from queue import PriorityQueue
 
 import networkx as nx
 from networkx.utils import UnionFind, not_implemented_for
 
 __all__ = [
-    'minimum_spanning_edges', 'maximum_spanning_edges',
-    'minimum_spanning_tree', 'maximum_spanning_tree',
+    "minimum_spanning_edges",
+    "maximum_spanning_edges",
+    "minimum_spanning_tree",
+    "maximum_spanning_tree",
+    "partition_spanning_tree",
+    "EdgePartition",
+    "SpanningTreeIterator",
 ]
 
 
-@not_implemented_for('multigraph')
-def boruvka_mst_edges(G, minimum=True, weight='weight',
-                      keys=False, data=True, ignore_nan=False):
+class EdgePartition(Enum):
+    """
+    An enum to store the state of an edge partition. The enum is written to the
+    edges of a graph before being pasted to `kruskal_mst_edges`. Options are:
+
+    - EdgePartition.OPEN
+    - EdgePartition.INCLUDED
+    - EdgePartition.EXCLUDED
+    """
+
+    OPEN = 0
+    INCLUDED = 1
+    EXCLUDED = 2
+
+
+@not_implemented_for("multigraph")
+def boruvka_mst_edges(
+    G, minimum=True, weight="weight", keys=False, data=True, ignore_nan=False
+):
     """Iterate over edges of a Borůvka's algorithm min/max spanning tree.
 
     Parameters
@@ -68,15 +84,15 @@ def boruvka_mst_edges(G, minimum=True, weight='weight',
 
         """
         sign = 1 if minimum else -1
-        minwt = float('inf')
+        minwt = float("inf")
         boundary = None
         for e in nx.edge_boundary(G, component, data=True):
             wt = e[-1].get(weight, 1) * sign
             if isnan(wt):
                 if ignore_nan:
                     continue
-                msg = "NaN found as an edge weight. Edge %s"
-                raise ValueError(msg % (e,))
+                msg = f"NaN found as an edge weight. Edge {e}"
+                raise ValueError(msg)
             if wt < minwt:
                 minwt = wt
                 boundary = e
@@ -120,9 +136,11 @@ def boruvka_mst_edges(G, minimum=True, weight='weight',
                 forest.union(u, v)
 
 
-def kruskal_mst_edges(G, minimum, weight='weight',
-                      keys=True, data=True, ignore_nan=False):
-    """Iterate over edges of a Kruskal's algorithm min/max spanning tree.
+def kruskal_mst_edges(
+    G, minimum, weight="weight", keys=True, data=True, ignore_nan=False, partition=None
+):
+    """
+    Iterate over edge of a Kruskal's algorithm min/max spanning tree.
 
     Parameters
     ----------
@@ -148,38 +166,64 @@ def kruskal_mst_edges(G, minimum, weight='weight',
         If a NaN is found as an edge weight normally an exception is raised.
         If `ignore_nan is True` then that edge is ignored instead.
 
+    partition : string (default: None)
+        The name of the edge attribute holding the partition data, if it exists.
+        Partition data is written to the edges using the `EdgePartition` enum.
+        If a partition exists, all included edges and none of the excluded edges
+        will appear in the final tree. Open edges may or may not be used.
+
+    Yields
+    ------
+    edge tuple
+        The edges as discovered by Kruskal's method. Each edge can
+        take the following forms: `(u, v)`, `(u, v, d)` or `(u, v, k, d)`
+        depending on the `key` and `data` parameters
     """
     subtrees = UnionFind()
     if G.is_multigraph():
         edges = G.edges(keys=True, data=True)
-
-        def filter_nan_edges(edges=edges, weight=weight):
-            sign = 1 if minimum else -1
-            for u, v, k, d in edges:
-                wt = d.get(weight, 1) * sign
-                if isnan(wt):
-                    if ignore_nan:
-                        continue
-                    msg = "NaN found as an edge weight. Edge %s"
-                    raise ValueError(msg % ((u, v, k, d),))
-                yield wt, u, v, k, d
     else:
         edges = G.edges(data=True)
 
-        def filter_nan_edges(edges=edges, weight=weight):
-            sign = 1 if minimum else -1
-            for u, v, d in edges:
-                wt = d.get(weight, 1) * sign
-                if isnan(wt):
-                    if ignore_nan:
-                        continue
-                    msg = "NaN found as an edge weight. Edge %s"
-                    raise ValueError(msg % ((u, v, d),))
-                yield wt, u, v, d
-    edges = sorted(filter_nan_edges(), key=itemgetter(0))
+    """
+    Sort the edges of the graph with respect to the partition data. 
+    Edges are returned in the following order:
+
+    * Included edges
+    * Open edges from smallest to largest weight
+    * Excluded edges
+    """
+    included_edges = []
+    open_edges = []
+    for e in edges:
+        d = e[-1]
+        wt = d.get(weight, 1)
+        if isnan(wt):
+            if ignore_nan:
+                continue
+            raise ValueError(f"NaN found as an edge weight. Edge {e}")
+
+        edge = (wt,) + e
+        if d.get(partition) == EdgePartition.INCLUDED:
+            included_edges.append(edge)
+        elif d.get(partition) == EdgePartition.EXCLUDED:
+            continue
+        else:
+            open_edges.append(edge)
+
+    if minimum:
+        sorted_open_edges = sorted(open_edges, key=itemgetter(0))
+    else:
+        sorted_open_edges = sorted(open_edges, key=itemgetter(0), reverse=True)
+
+    # Condense the lists into one
+    included_edges.extend(sorted_open_edges)
+    sorted_edges = included_edges
+    del open_edges, sorted_open_edges, included_edges
+
     # Multigraphs need to handle edge keys in addition to edge data.
     if G.is_multigraph():
-        for wt, u, v, k, d in edges:
+        for wt, u, v, k, d in sorted_edges:
             if subtrees[u] != subtrees[v]:
                 if keys:
                     if data:
@@ -193,17 +237,16 @@ def kruskal_mst_edges(G, minimum, weight='weight',
                         yield u, v
                 subtrees.union(u, v)
     else:
-        for wt, u, v, d in edges:
+        for wt, u, v, d in sorted_edges:
             if subtrees[u] != subtrees[v]:
                 if data:
-                    yield (u, v, d)
+                    yield u, v, d
                 else:
-                    yield (u, v)
+                    yield u, v
                 subtrees.union(u, v)
 
 
-def prim_mst_edges(G, minimum, weight='weight',
-                   keys=True, data=True, ignore_nan=False):
+def prim_mst_edges(G, minimum, weight="weight", keys=True, data=True, ignore_nan=False):
     """Iterate over edges of Prim's algorithm min/max spanning tree.
 
     Parameters
@@ -235,15 +278,15 @@ def prim_mst_edges(G, minimum, weight='weight',
     push = heappush
     pop = heappop
 
-    nodes = list(G)
+    nodes = set(G)
     c = count()
 
     sign = 1 if minimum else -1
 
     while nodes:
-        u = nodes.pop(0)
+        u = nodes.pop()
         frontier = []
-        visited = [u]
+        visited = {u}
         if is_multigraph:
             for v, keydict in G.adj[u].items():
                 for k, d in keydict.items():
@@ -251,8 +294,8 @@ def prim_mst_edges(G, minimum, weight='weight',
                     if isnan(wt):
                         if ignore_nan:
                             continue
-                        msg = "NaN found as an edge weight. Edge %s"
-                        raise ValueError(msg % ((u, v, k, d),))
+                        msg = f"NaN found as an edge weight. Edge {(u, v, k, d)}"
+                        raise ValueError(msg)
                     push(frontier, (wt, next(c), u, v, k, d))
         else:
             for v, d in G.adj[u].items():
@@ -260,15 +303,15 @@ def prim_mst_edges(G, minimum, weight='weight',
                 if isnan(wt):
                     if ignore_nan:
                         continue
-                    msg = "NaN found as an edge weight. Edge %s"
-                    raise ValueError(msg % ((u, v, d),))
+                    msg = f"NaN found as an edge weight. Edge {(u, v, d)}"
+                    raise ValueError(msg)
                 push(frontier, (wt, next(c), u, v, d))
         while frontier:
             if is_multigraph:
                 W, _, u, v, k, d = pop(frontier)
             else:
                 W, _, u, v, d = pop(frontier)
-            if v in visited:
+            if v in visited or v not in nodes:
                 continue
             # Multigraphs need to handle edge keys in addition to edge data.
             if is_multigraph and keys:
@@ -282,8 +325,8 @@ def prim_mst_edges(G, minimum, weight='weight',
                 else:
                     yield u, v
             # update frontier
-            visited.append(v)
-            nodes.remove(v)
+            visited.add(v)
+            nodes.discard(v)
             if is_multigraph:
                 for w, keydict in G.adj[v].items():
                     if w in visited:
@@ -300,16 +343,17 @@ def prim_mst_edges(G, minimum, weight='weight',
 
 
 ALGORITHMS = {
-    'boruvka': boruvka_mst_edges,
-    u'borůvka': boruvka_mst_edges,
-    'kruskal': kruskal_mst_edges,
-    'prim': prim_mst_edges
+    "boruvka": boruvka_mst_edges,
+    "borůvka": boruvka_mst_edges,
+    "kruskal": kruskal_mst_edges,
+    "prim": prim_mst_edges,
 }
 
 
-@not_implemented_for('directed')
-def minimum_spanning_edges(G, algorithm='kruskal', weight='weight',
-                           keys=True, data=True, ignore_nan=False):
+@not_implemented_for("directed")
+def minimum_spanning_edges(
+    G, algorithm="kruskal", weight="weight", keys=True, data=True, ignore_nan=False
+):
     """Generate edges in a minimum spanning forest of an undirected
     weighted graph.
 
@@ -363,19 +407,19 @@ def minimum_spanning_edges(G, algorithm='kruskal', weight='weight',
 
     >>> G = nx.cycle_graph(4)
     >>> G.add_edge(0, 3, weight=2)
-    >>> mst = tree.minimum_spanning_edges(G, algorithm='kruskal', data=False)
+    >>> mst = tree.minimum_spanning_edges(G, algorithm="kruskal", data=False)
     >>> edgelist = list(mst)
-    >>> sorted(edgelist)
-    [(0, 1), (1, 2), (2, 3)]
+    >>> sorted(sorted(e) for e in edgelist)
+    [[0, 1], [1, 2], [2, 3]]
 
     Find minimum spanning edges by Prim's algorithm
 
     >>> G = nx.cycle_graph(4)
     >>> G.add_edge(0, 3, weight=2)
-    >>> mst = tree.minimum_spanning_edges(G, algorithm='prim', data=False)
+    >>> mst = tree.minimum_spanning_edges(G, algorithm="prim", data=False)
     >>> edgelist = list(mst)
-    >>> sorted(edgelist)
-    [(0, 1), (1, 2), (2, 3)]
+    >>> sorted(sorted(e) for e in edgelist)
+    [[0, 1], [1, 2], [2, 3]]
 
     Notes
     -----
@@ -391,17 +435,19 @@ def minimum_spanning_edges(G, algorithm='kruskal', weight='weight',
     """
     try:
         algo = ALGORITHMS[algorithm]
-    except KeyError:
-        msg = '{} is not a valid choice for an algorithm.'.format(algorithm)
-        raise ValueError(msg)
+    except KeyError as err:
+        msg = f"{algorithm} is not a valid choice for an algorithm."
+        raise ValueError(msg) from err
 
-    return algo(G, minimum=True, weight=weight, keys=keys, data=data,
-                ignore_nan=ignore_nan)
+    return algo(
+        G, minimum=True, weight=weight, keys=keys, data=data, ignore_nan=ignore_nan
+    )
 
 
-@not_implemented_for('directed')
-def maximum_spanning_edges(G, algorithm='kruskal', weight='weight',
-                           keys=True, data=True, ignore_nan=False):
+@not_implemented_for("directed")
+def maximum_spanning_edges(
+    G, algorithm="kruskal", weight="weight", keys=True, data=True, ignore_nan=False
+):
     """Generate edges in a maximum spanning forest of an undirected
     weighted graph.
 
@@ -455,19 +501,19 @@ def maximum_spanning_edges(G, algorithm='kruskal', weight='weight',
 
     >>> G = nx.cycle_graph(4)
     >>> G.add_edge(0, 3, weight=2)
-    >>> mst = tree.maximum_spanning_edges(G, algorithm='kruskal', data=False)
+    >>> mst = tree.maximum_spanning_edges(G, algorithm="kruskal", data=False)
     >>> edgelist = list(mst)
-    >>> sorted(edgelist)
-    [(0, 1), (0, 3), (1, 2)]
+    >>> sorted(sorted(e) for e in edgelist)
+    [[0, 1], [0, 3], [1, 2]]
 
     Find maximum spanning edges by Prim's algorithm
 
     >>> G = nx.cycle_graph(4)
-    >>> G.add_edge(0, 3, weight=2) # assign weight 2 to edge 0-3
-    >>> mst = tree.maximum_spanning_edges(G, algorithm='prim', data=False)
+    >>> G.add_edge(0, 3, weight=2)  # assign weight 2 to edge 0-3
+    >>> mst = tree.maximum_spanning_edges(G, algorithm="prim", data=False)
     >>> edgelist = list(mst)
-    >>> sorted(edgelist)
-    [(0, 1), (0, 3), (3, 2)]
+    >>> sorted(sorted(e) for e in edgelist)
+    [[0, 1], [0, 3], [2, 3]]
 
     Notes
     -----
@@ -482,16 +528,16 @@ def maximum_spanning_edges(G, algorithm='kruskal', weight='weight',
     """
     try:
         algo = ALGORITHMS[algorithm]
-    except KeyError:
-        msg = '{} is not a valid choice for an algorithm.'.format(algorithm)
-        raise ValueError(msg)
+    except KeyError as err:
+        msg = f"{algorithm} is not a valid choice for an algorithm."
+        raise ValueError(msg) from err
 
-    return algo(G, minimum=False, weight=weight, keys=keys, data=data,
-                ignore_nan=ignore_nan)
+    return algo(
+        G, minimum=False, weight=weight, keys=keys, data=data, ignore_nan=ignore_nan
+    )
 
 
-def minimum_spanning_tree(G, weight='weight', algorithm='kruskal',
-                          ignore_nan=False):
+def minimum_spanning_tree(G, weight="weight", algorithm="kruskal", ignore_nan=False):
     """Returns a minimum spanning tree or forest on an undirected graph `G`.
 
     Parameters
@@ -540,8 +586,9 @@ def minimum_spanning_tree(G, weight='weight', algorithm='kruskal',
     Isolated nodes with self-loops are in the tree as edgeless isolated nodes.
 
     """
-    edges = minimum_spanning_edges(G, algorithm, weight, keys=True,
-                                   data=True, ignore_nan=ignore_nan)
+    edges = minimum_spanning_edges(
+        G, algorithm, weight, keys=True, data=True, ignore_nan=ignore_nan
+    )
     T = G.__class__()  # Same graph class as G
     T.graph.update(G.graph)
     T.add_nodes_from(G.nodes.items())
@@ -549,8 +596,70 @@ def minimum_spanning_tree(G, weight='weight', algorithm='kruskal',
     return T
 
 
-def maximum_spanning_tree(G, weight='weight', algorithm='kruskal',
-                          ignore_nan=False):
+def partition_spanning_tree(
+    G, minimum=True, weight="weight", partition="partition", ignore_nan=False
+):
+    """
+    Find a spanning tree while respecting a partition of edges.
+
+    Edges can be flagged as either `INLCUDED` which are required to be in the
+    returned tree, `EXCLUDED`, which cannot be in the returned tree and `OPEN`.
+
+    This is used in the SpanningTreeIterator to create new partitions following
+    the algorithm of Sörensen and Janssens [1]_.
+
+    Parameters
+    ----------
+    G : undirected graph
+        An undirected graph.
+
+    minimum : bool (default: True)
+        Determines whether the returned tree is the minimum spanning tree of
+        the partition of the maximum one.
+
+    weight : str
+        Data key to use for edge weights.
+
+    partition : str
+        The key for the edge attribute containing the partition
+        data on the graph. Edges can be included, excluded or open using the
+        `EdgePartition` enum.
+
+    ignore_nan : bool (default: False)
+        If a NaN is found as an edge weight normally an exception is raised.
+        If `ignore_nan is True` then that edge is ignored instead.
+
+
+    Returns
+    -------
+    G : NetworkX Graph
+        A minimum spanning tree using all of the included edges in the graph and
+        none of the excluded edges.
+
+    References
+    ----------
+    .. [1] G.K. Janssens, K. Sörensen, An algorithm to generate all spanning
+           trees in order of increasing cost, Pesquisa Operacional, 2005-08,
+           Vol. 25 (2), p. 219-229,
+           https://www.scielo.br/j/pope/a/XHswBwRwJyrfL88dmMwYNWp/?lang=en
+    """
+    edges = kruskal_mst_edges(
+        G,
+        minimum,
+        weight,
+        keys=True,
+        data=True,
+        ignore_nan=ignore_nan,
+        partition=partition,
+    )
+    T = G.__class__()  # Same graph class as G
+    T.graph.update(G.graph)
+    T.add_nodes_from(G.nodes.items())
+    T.add_edges_from(edges)
+    return T
+
+
+def maximum_spanning_tree(G, weight="weight", algorithm="kruskal", ignore_nan=False):
     """Returns a maximum spanning tree or forest on an undirected graph `G`.
 
     Parameters
@@ -601,11 +710,180 @@ def maximum_spanning_tree(G, weight='weight', algorithm='kruskal',
     Isolated nodes with self-loops are in the tree as edgeless isolated nodes.
 
     """
-    edges = maximum_spanning_edges(G, algorithm, weight, keys=True,
-                                   data=True, ignore_nan=ignore_nan)
+    edges = maximum_spanning_edges(
+        G, algorithm, weight, keys=True, data=True, ignore_nan=ignore_nan
+    )
     edges = list(edges)
     T = G.__class__()  # Same graph class as G
     T.graph.update(G.graph)
     T.add_nodes_from(G.nodes.items())
     T.add_edges_from(edges)
     return T
+
+
+class SpanningTreeIterator:
+    """
+    Iterate over all spanning trees of a graph in either increasing or
+    decreasing cost.
+
+    Notes
+    -----
+    This iterator uses the partition scheme from [1]_ (included edges,
+    excluded edges and open edges) as well as a modified Kruskal's Algorithm
+    to generate minimum spanning trees which respect the partition of edges.
+    For spanning trees with the same weight, ties are broken arbitrarily.
+
+    References
+    ----------
+    .. [1] G.K. Janssens, K. Sörensen, An algorithm to generate all spanning
+           trees in order of increasing cost, Pesquisa Operacional, 2005-08,
+           Vol. 25 (2), p. 219-229,
+           https://www.scielo.br/j/pope/a/XHswBwRwJyrfL88dmMwYNWp/?lang=en
+    """
+
+    @dataclass(order=True)
+    class Partition:
+        """
+        This dataclass represents a partition and stores a dict with the edge
+        data and the weight of the minimum spanning tree of the partition dict.
+        """
+
+        mst_weight: float
+        partition_dict: dict = field(compare=False)
+
+        def __copy__(self):
+            return SpanningTreeIterator.Partition(
+                self.mst_weight, self.partition_dict.copy()
+            )
+
+    def __init__(self, G, weight="weight", minimum=True, ignore_nan=False):
+        """
+        Initialize the iterator
+
+        Parameters
+        ----------
+        G : nx.Graph
+            The directed graph which we need to iterate trees over
+
+        weight : String, default = "weight"
+            The edge attribute used to store the weight of the edge
+
+        minimum : bool, default = True
+            Return the trees in increasing order while true and decreasing order
+            while false.
+
+        ignore_nan : bool, default = False
+            If a NaN is found as an edge weight normally an exception is raised.
+            If `ignore_nan is True` then that edge is ignored instead.
+        """
+        self.G = G.copy()
+        self.weight = weight
+        self.minimum = minimum
+        self.ignore_nan = ignore_nan
+        # Randomly create a key for an edge attribute to hold the partition data
+        self.partition_key = (
+            "SpanningTreeIterators super secret partition attribute name"
+        )
+
+    def __iter__(self):
+        """
+        Returns
+        -------
+        SpanningTreeIterator
+            The iterator object for this graph
+        """
+        self.partition_queue = PriorityQueue()
+        self._clear_partition(self.G)
+        mst_weight = partition_spanning_tree(
+            self.G, self.minimum, self.weight, self.partition_key, self.ignore_nan
+        ).size(weight=self.weight)
+
+        self.partition_queue.put(
+            self.Partition(mst_weight if self.minimum else -mst_weight, dict())
+        )
+
+        return self
+
+    def __next__(self):
+        """
+        Returns
+        -------
+        (multi)Graph
+            The spanning tree of next greatest weight, which ties broken
+            arbitrarily.
+        """
+        if self.partition_queue.empty():
+            del self.G, self.partition_queue
+            raise StopIteration
+
+        partition = self.partition_queue.get()
+        self._write_partition(partition)
+        next_tree = partition_spanning_tree(
+            self.G, self.minimum, self.weight, self.partition_key, self.ignore_nan
+        )
+        self._partition(partition, next_tree)
+
+        self._clear_partition(next_tree)
+        return next_tree
+
+    def _partition(self, partition, partition_tree):
+        """
+        Create new partitions based of the minimum spanning tree of the
+        current minimum partition.
+
+        Parameters
+        ----------
+        partition : Partition
+            The Partition instance used to generate the current minimum spanning
+            tree.
+        partition_tree : nx.Graph
+            The minimum spanning tree of the input partition.
+        """
+        # create two new partitions with the data from the input partition dict
+        p1 = self.Partition(0, partition.partition_dict.copy())
+        p2 = self.Partition(0, partition.partition_dict.copy())
+        for e in partition_tree.edges:
+            # determine if the edge was open or included
+            if e not in partition.partition_dict:
+                # This is an open edge
+                p1.partition_dict[e] = EdgePartition.EXCLUDED
+                p2.partition_dict[e] = EdgePartition.INCLUDED
+
+                self._write_partition(p1)
+                p1_mst = partition_spanning_tree(
+                    self.G,
+                    self.minimum,
+                    self.weight,
+                    self.partition_key,
+                    self.ignore_nan,
+                )
+                p1_mst_weight = p1_mst.size(weight=self.weight)
+                if nx.is_connected(p1_mst):
+                    p1.mst_weight = p1_mst_weight if self.minimum else -p1_mst_weight
+                    self.partition_queue.put(p1.__copy__())
+                p1.partition_dict = p2.partition_dict.copy()
+
+    def _write_partition(self, partition):
+        """
+        Writes the desired partition into the graph to calculate the minimum
+        spanning tree.
+
+        Parameters
+        ----------
+        partition : Partition
+            A Partition dataclass describing a partition on the edges of the
+            graph.
+        """
+        for u, v, d in self.G.edges(data=True):
+            if (u, v) in partition.partition_dict:
+                d[self.partition_key] = partition.partition_dict[(u, v)]
+            else:
+                d[self.partition_key] = EdgePartition.OPEN
+
+    def _clear_partition(self, G):
+        """
+        Removes partition data from the graph
+        """
+        for u, v, d in G.edges(data=True):
+            if self.partition_key in d:
+                del d[self.partition_key]
